package com.luojigou.product.intro

import android.util.Log
import android.view.View
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.contract.ActivityResultContracts
import com.luojigou.product.R
import com.luojigou.product.base.BaseActivity
import com.luojigou.product.utils.PermissionUtils

abstract class AbsIntroduceActivity : BaseActivity(), View.OnClickListener,
    IntroducePermissionFragment.Host {

    private lateinit var permissionUtils: PermissionUtils

    private lateinit var requestPermission: ActivityResultLauncher<Array<String>>

    override fun onCreate(savedInstanceState: android.os.Bundle?) {
        super.onCreate(savedInstanceState)
        setTitle("连接引导")
        requestPermission =
            registerForActivityResult(ActivityResultContracts.RequestMultiplePermissions()) {
                if (it.all { permission -> permission.value }) {
                    setFragment(IntroduceNormalFragment())
                } else {
                    Log.e("XDScanWifiActivity", "requestPermission: 权限被拒绝")
                }
            }
        permissionUtils = PermissionUtils(this)
        checkAndSetFragment()
    }

    private fun checkAndSetFragment() {
        if (permissionUtils.checkAllPermissions()) {
            setFragment(IntroduceNormalFragment())
        } else {
            setFragment(IntroducePermissionFragment(this))
        }
    }

    override fun getLayoutId(): Int = R.layout.activity_introduce

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.btn_intro_start -> startActivity()
        }
    }

    override fun requestPermission() {
        requestPermission.launch(permissionUtils.requestAllPermissions())
    }

    abstract fun startActivity()
}